diff --git a/Make-MinGW.bat b/Make-MinGW.bat
index 66e5e4db0..88fba68db 100644
--- a/Make-MinGW.bat
+++ b/Make-MinGW.bat
@@ -5,8 +5,10 @@ REM ****************************************************************
 SET WD=%CD%
 SET "PGBUILDPATH=%WD%\win-build"
 SET CMDOPTION=""
+SET ISPROD="YES"
 IF "%1" == "clean"  SET CMDOPTION="VALID"
 IF "%1" == "x86"    SET CMDOPTION="VALID"
+IF "%2" == "dev"    SET ISPROD="NO"
 
 IF NOT %CMDOPTION%=="VALID"  ( GOTO USAGE )
 SET ARCHITECTURE=%1
@@ -168,7 +170,11 @@ REM Main function Ends
     ECHO Install Javascript dependencies
     call yarn install
     ECHO Bundle all Javascript
-    call yarn run bundle
+    IF %ISPROD%=="YES" (
+      call yarn run bundle:prod
+    ) ELSE (
+      call yarn run bundle:dev
+    )
 
     XCOPY /S /I /E /H /Y "%WD%\web" "%PGBUILDPATH%\web" > nul
     IF %ERRORLEVEL% NEQ 0 EXIT /B %ERRORLEVEL%
diff --git a/Make.bat b/Make.bat
index 499ebac25..69e83de50 100644
--- a/Make.bat
+++ b/Make.bat
@@ -5,9 +5,11 @@ REM ****************************************************************
 SET WD=%CD%
 SET "PGBUILDPATH=%WD%\win-build"
 SET CMDOPTION=""
+SET ISPROD="YES"
 IF "%1" == "clean"  SET CMDOPTION="VALID"
 IF "%1" == "x86"    SET CMDOPTION="VALID"
 IF "%1" == "amd64"  SET CMDOPTION="VALID"
+IF "%2" == "dev"    SET ISPROD="NO"
 
 IF NOT %CMDOPTION%=="VALID"  ( GOTO USAGE )
 SET ARCHITECTURE=%1
@@ -242,7 +244,11 @@ REM Main function Ends
     ECHO Install Javascript dependencies
     call yarn install
     ECHO Bundle all Javascript
-    call yarn run bundle
+    IF %ISPROD%=="YES" (
+      call yarn run bundle:prod
+    ) ELSE (
+      call yarn run bundle:dev
+    )
 
     XCOPY /S /I /E /H /Y "%WD%\web" "%PGBUILDPATH%\web" > nul
     IF %ERRORLEVEL% NEQ 0 EXIT /B %ERRORLEVEL%
diff --git a/Makefile b/Makefile
index ab1026221..5f303622e 100644
--- a/Makefile
+++ b/Makefile
@@ -17,16 +17,25 @@ SHELL = /bin/sh
 all: docs pip src
 
 appbundle: docs
-	./pkg/mac/build.sh
+	RUN_BUILD_IN_DEV=0 ./pkg/mac/build.sh
+
+appbundle-dev: docs
+	RUN_BUILD_IN_DEV=1 ./pkg/mac/build.sh
+
+appbundle-dev-webkit: docs
+	RUN_BUILD_IN_DEV=1 PGADMIN4_USE_WEBKIT=1 ./pkg/mac/build.sh
 
 appbundle-webkit: docs
-	PGADMIN4_USE_WEBKIT=1 ./pkg/mac/build.sh
+	RUN_BUILD_IN_DEV=0 PGADMIN4_USE_WEBKIT=1 ./pkg/mac/build.sh
 
 install-node:
 	cd web && yarn install
 
+bundle-dev:
+	cd web && yarn run bundle:dev
+
 bundle:
-	cd web && yarn run bundle
+	cd web && yarn run bundle:prod
 
 linter:
 	cd web && yarn run linter
@@ -34,10 +43,13 @@ linter:
 check: install-node bundle linter
 	cd web && yarn run karma start -- --single-run && python regression/runtests.py
 
-check-python: install-node bundle
+check-dev: install-node bundle-dev linter
+	cd web && yarn run karma start -- --single-run && python regression/runtests.py
+
+check-python: install-node bundle-dev
 	cd web && python regression/runtests.py --exclude feature_tests
 
-check-feature: install-node bundle
+check-feature: install-node bundle-dev
 	cd web && python regression/runtests.py --pkg feature_tests
 
 check-js: install-node linter
@@ -76,7 +88,13 @@ msg-update:
 .PHONY: docs
 
 pip: docs
-	./pkg/pip/build.sh
+	RUN_BUILD_IN_DEV=0 ./pkg/pip/build.sh
+
+pip-dev: docs
+	RUN_BUILD_IN_DEV=1 ./pkg/pip/build.sh
 
 src:
-	./pkg/src/build.sh
+	RUN_BUILD_IN_DEV=0 ./pkg/src/build.sh
+
+src-dev:
+	RUN_BUILD_IN_DEV=1 ./pkg/src/build.sh
diff --git a/pkg/mac/build.sh b/pkg/mac/build.sh
index 870216587..11a6297e0 100755
--- a/pkg/mac/build.sh
+++ b/pkg/mac/build.sh
@@ -180,7 +180,11 @@ _complete_bundle() {
 
     pushd $SOURCEDIR/web
         yarn install
-        yarn run bundle
+        if [ "$RUN_BUILD_IN_DEV" == "1" ]; then
+            yarn run bundle:dev
+        else
+            yarn run bundle:prod
+        fi
     popd
 
     # copy the web directory to the bundle as it is required by runtime
diff --git a/pkg/pip/build.sh b/pkg/pip/build.sh
index 4704475a1..e16ede806 100755
--- a/pkg/pip/build.sh
+++ b/pkg/pip/build.sh
@@ -58,7 +58,11 @@ do
 done
 
 yarn install
-yarn run bundle
+if [ "$RUN_BUILD_IN_DEV" == "1" ]; then
+    yarn run bundle:dev
+else
+    yarn run bundle:prod
+fi
 
 for FILE in `ls -d pgAdmin/static/js/generated/*`
 do
diff --git a/pkg/src/build.sh b/pkg/src/build.sh
index 83c6dc054..5616c2eb6 100755
--- a/pkg/src/build.sh
+++ b/pkg/src/build.sh
@@ -71,7 +71,11 @@ done
 
 pushd web
     yarn install
-    yarn run bundle
+    if [ "$RUN_BUILD_IN_DEV" == "1" ]; then
+        yarn run bundle:dev
+    else
+        yarn run bundle:prod
+    fi
 
     for FILE in `ls -d pgAdmin/static/js/generated/*`
     do
